<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Identification faciale</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Vérification réussie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Vérifier votre identifiant de visage</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID verrouillé, utiliser le mot de passe s&apos;il vous plaît</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Appareil indisponible !</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Vérifier votre empreinte digitale</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Vérification réussie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>La vérification a échoué, %n chance restante</numerusform><numerusform>La vérification a échoué, %n chances restantes</numerusform><numerusform>La vérification a échoué, %n chances restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Empreinte digitale verrouillée, veuillez utiliser le mot de passe, s&apos;il vous plaît</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID d&apos;iris</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Vérification réussie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Vérifier votre identifiant Iris</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID verrouillé, utilisez le mot de passe s&apos;il vous plaît</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Vérification réussie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>La vérification a échoué, %n chance restante</numerusform><numerusform>La vérification a échoué, %n chances restantes</numerusform><numerusform>La vérification a échoué, %n chances restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Mauvais mot de passe</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Veuillez réessayer dans 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>réinitialiser le mot de passe</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Mot de passe oublié ?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Veuillez réessayer dans 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Veuillez réessayer %n minute plus tard</numerusform><numerusform>Veuillez réessayer %n minutes plus tard</numerusform><numerusform>Veuillez réessayer %n minutes plus tard</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Réinitialiser le mot de passe</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Mot de passe oublié ?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Vérification réussie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>La vérification a échoué, %n chance restante</numerusform><numerusform>La vérification a échoué, %n chances restantes</numerusform><numerusform>La vérification a échoué, %n chances restantes</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>La vérification a échoué, il ne vous reste plus qu&apos;un seul essai</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Mauvais code PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey est requis</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Entrer votre code PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Veuillez réessayer %n minute plus tard</numerusform><numerusform>Veuillez réessayer %n minute(s) plus tard</numerusform><numerusform>Veuillez réessayer %n minute(s) plus tard</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Veuillez réessayer dans 1 minute</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Compte</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Mot de passe expiré, veuillez le modifier</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Mauvais compte</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Mauvais mot de passe</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Écran verrouillé</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Impossible de verrouiller l&apos;écran</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Aucune correspondance trouvée pour cette empreinte digitale, veuillez entrer votre mot de passe manuellement.</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Impossible de faire correspondre l&apos;empreinte digitale.</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Les utilisateurs ci-dessus sont toujours connectés, des données seront perdues si vous éteignez l&apos;ordinateur, êtes-vous sûr de vouloir poursuivre?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Les utilisateurs ci-dessus sont toujours connectés, des données seront perdues si vous redémarrez l&apos;ordinateur, êtes-vous sûr de vouloir poursuivre?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Vous avez activé le niveau de sécurité élevé du système, vous ne pouvez donc pas passer en mode Wayland, veuillez désactiver le niveau de sécurité élevé dans Security Center et réessayer.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mise en veille </translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Mise en veille prolongée</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Fermer à clé</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Se déconnecter</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Changer d&apos;utilisateur</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Système de commutation</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Démarrer le moniteur système</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Les programmes empêchent l&apos;ordinateur de s&apos;éteindre et forcer l&apos;arrêt peut entraîner une perte de données.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Pour fermer le programme, cliquer sur Annuler, puis fermer le programme.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Les programmes empêchent l&apos;ordinateur de redémarrer et forcer le redémarrage peut entraîner une perte de données.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Les programmes empêchent l&apos;ordinateur de se suspendre et forcer la suspension peut entraîner une perte de données.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Les programmes empêchent l&apos;ordinateur de mettre en veille prolongée et forcer la mise en veille prolongée peut entraîner une perte de données.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Les programmes empêchent l&apos;ordinateur de se déconnecter et forcer la déconnexion peut entraîner une perte de données.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Eteindre</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Mise en veille prolongée</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Se déconnecter</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Êtes-vous sûr de vouloir arrêter ?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Êtes-vous sûr de vouloir redémarrer ?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Êtes-vous sûr de vouloir vous déconnecter ?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Allumer</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Éteindre</translation>
    </message>
</context>
</TS>